@@ -30,6 +30,8 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityMovingNegativeDifferenceAve
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingRSI
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingLogReturn
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingResidue
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingRank
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingCorrelation
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingHistoricalWindow
 
 
@@ -525,10 +527,10 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                     expected = pos_avg.value[name] / (pos_avg.value[name] - neg_avg.value[name]) * 100
                     calculated = value[name]
                     self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
-                                                                         'expected:   {1:.12f}\n'
-                                                                         'calculated: {2:.12f}'.format(i,
-                                                                                                       expected,
-                                                                                                       calculated))
+                                                                     'expected:   {1:.12f}\n'
+                                                                     'calculated: {2:.12f}'.format(i,
+                                                                                                   expected,
+                                                                                                   calculated))
 
     def testSecurityMovingRSIDeepcopy(self):
         self.template_test_deepcopy(SecurityMovingRSI, window=10, dependency='x')
@@ -739,7 +741,7 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                 self.assertAlmostEqual(np.mean((container)), compounded2.value['aapl'], 12)
 
     def testSecurityMovingResidue(self):
-        window =100
+        window = 100
         mr = SecurityMovingResidue(window, ('y', 'x'))
         for i in range(len(self.aapl['close'])):
             data = {'aapl': {'y': self.aapl['close'][i], 'x': self.aapl['open'][i]},
@@ -752,9 +754,9 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                     series_y = getattr(self, name)['close'][i - window + 1:i + 1]
                     expected_res = series_y[-1] - np.dot(series_x, series_y) / np.dot(series_x, series_x) * series_x[-1]
                     self.assertAlmostEqual(mr.value[name], expected_res, msg= \
-                                           "at index {0} and symbol {1}\n"
-                                           "expected:   {2}\n"
-                                           "calculated: {3}".format(i, name, expected_res, mr.value[name]))
+                        "at index {0} and symbol {1}\n"
+                        "expected:   {2}\n"
+                        "calculated: {3}".format(i, name, expected_res, mr.value[name]))
 
     def testSecurityMovingResidueDeepcopy(self):
         ma = SecurityMovingResidue(10, ['y', 'x'])
@@ -810,3 +812,145 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                 for name in ma.value.index():
                     self.assertAlmostEqual(ma.value[name], pickled.value[name])
 
+    def testSecurityMovingCorrelation(self):
+        window = 100
+        mr = SecurityMovingCorrelation(window, ('y', 'x'))
+        for i in range(len(self.aapl['close'])):
+            data = {'aapl': {'y': self.aapl['close'][i], 'x': self.aapl['open'][i]},
+                    'ibm': {'y': self.ibm['close'][i], 'x': self.ibm['open'][i]}}
+            mr.push(data)
+
+            if i >= window - 1:
+                for name in mr.value.index():
+                    series_x = getattr(self, name)['open'][i - window + 1:i + 1]
+                    series_y = getattr(self, name)['close'][i - window + 1:i + 1]
+                    expected_res = np.corrcoef(series_x, series_y)[0, 1]
+                    self.assertAlmostEqual(mr.value[name], expected_res, msg= \
+                        "at index {0} and symbol {1}\n"
+                        "expected:   {2}\n"
+                        "calculated: {3}".format(i, name, expected_res, mr.value[name]))
+
+    def testSecurityMovingCorrelationDeepcopy(self):
+        ma = SecurityMovingCorrelation(10, ['y', 'x'])
+
+        data = dict(aapl=dict(x=1., y=2),
+                    ibm=dict(x=2., y=3))
+        data2 = dict(aapl=dict(x=2., y=3),
+                     ibm=dict(x=3., y=4))
+
+        ma.push(data)
+        ma.push(data2)
+
+        copied = copy.deepcopy(ma)
+
+        for i, v in enumerate(np.random.rand(20)):
+            data['aapl']['x'] = v
+            data['aapl']['y'] = v + 1
+            data['ibm']['x'] = v + 1.
+            data['ibm']['y'] = v + 2.
+            ma.push(data)
+            copied.push(data)
+            if i >= 10:
+                for name in ma.value.index():
+                    self.assertAlmostEqual(ma.value[name], copied.value[name])
+
+    def testSecurityMovingCorrelationPickle(self):
+        ma = SecurityMovingCorrelation(10, ['y', 'x'])
+
+        data = dict(aapl=dict(x=1., y=2),
+                    ibm=dict(x=2., y=3))
+        data2 = dict(aapl=dict(x=2., y=3),
+                     ibm=dict(x=3., y=4))
+
+        ma.push(data)
+        ma.push(data2)
+
+        with tempfile.NamedTemporaryFile('w+b', delete=False) as f:
+            pickle.dump(ma, f)
+
+        with open(f.name, 'rb') as f2:
+            pickled = pickle.load(f2)
+        os.unlink(f.name)
+
+        for i, v in enumerate(np.random.rand(20)):
+            data['aapl']['x'] = v
+            data['aapl']['y'] = v + 1
+            data['ibm']['x'] = v + 1.
+            data['ibm']['y'] = v + 2.
+            ma.push(data)
+            pickled.push(data)
+
+            if i >= 10:
+                for name in ma.value.index():
+                    self.assertAlmostEqual(ma.value[name], pickled.value[name])
+
+    def testSecurityMovingRank(self):
+        window = 100
+        mr = SecurityMovingRank(window, 'x')
+        for i in range(len(self.aapl['close'])):
+            data = {'aapl': {'y': self.aapl['close'][i], 'x': self.aapl['open'][i]},
+                    'ibm': {'y': self.ibm['close'][i], 'x': self.ibm['open'][i]}}
+            mr.push(data)
+
+            if i >= window - 1:
+                for name in mr.value.index():
+                    series_x = getattr(self, name)['open'][i - window + 1:i + 1]
+                    expected_res = np.argsort(series_x.argsort())[-1]
+                    self.assertAlmostEqual(mr.value[name], expected_res, msg= \
+                        "at index {0} and symbol {1}\n"
+                        "expected:   {2}\n"
+                        "calculated: {3}".format(i, name, expected_res, mr.value[name]))
+
+    def testSecurityMovingRankDeepcopy(self):
+        ma = SecurityMovingRank(10, 'x')
+
+        data = dict(aapl=dict(x=1., y=2),
+                    ibm=dict(x=2., y=3))
+        data2 = dict(aapl=dict(x=2., y=3),
+                     ibm=dict(x=3., y=4))
+
+        ma.push(data)
+        ma.push(data2)
+
+        copied = copy.deepcopy(ma)
+
+        for i, v in enumerate(np.random.rand(20)):
+            data['aapl']['x'] = v
+            data['aapl']['y'] = v + 0.1
+            data['ibm']['x'] = v + 0.1
+            data['ibm']['y'] = v + 0.2
+            ma.push(data)
+            copied.push(data)
+            if i >= 10:
+                for name in ma.value.index():
+                    self.assertAlmostEqual(ma.value[name], copied.value[name])
+
+    def testSecurityMovingRankPickle(self):
+        ma = SecurityMovingRank(10, 'x')
+
+        data = dict(aapl=dict(x=1., y=2),
+                    ibm=dict(x=2., y=3))
+        data2 = dict(aapl=dict(x=2., y=3),
+                     ibm=dict(x=3., y=4))
+
+        ma.push(data)
+        ma.push(data2)
+
+        with tempfile.NamedTemporaryFile('w+b', delete=False) as f:
+            pickle.dump(ma, f)
+
+        with open(f.name, 'rb') as f2:
+            pickled = pickle.load(f2)
+        os.unlink(f.name)
+
+        for i, v in enumerate(np.random.rand(20)):
+            data['aapl']['x'] = v
+            data['aapl']['y'] = v + 0.1
+            data['ibm']['x'] = v + 0.1
+            data['ibm']['y'] = v + 0.2
+            ma.push(data)
+            pickled.push(data)
+
+            if i >= 10:
+                for name in ma.value.index():
+                    self.assertAlmostEqual(ma.value[name], pickled.value[name])
