@@ -22,7 +22,7 @@ from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityConstArrayValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
-from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMinimum
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMin
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingSum
 
 
@@ -178,6 +178,27 @@ class TestSecurityValueHolders(unittest.TestCase):
                 else:
                     self.assertFalse(calculated[name])
 
+    def testSecurityXorOperatorValueHolder(self):
+        benchmark = SecurityLatestValueHolder(dependency='close') > 0
+        benchmark2 = SecurityLatestValueHolder(dependency='open') > 0
+
+        testValueHolder = benchmark ^ benchmark2
+
+        for i in range(len(self.datas['aapl']['close'])):
+            data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
+                    'ibm': {Factors.CLOSE: self.datas['ibm'][Factors.CLOSE][i],
+                            Factors.OPEN: self.datas['ibm'][Factors.OPEN][i]}}
+            testValueHolder.push(data)
+            calculated = testValueHolder.value
+
+            for name in calculated.index():
+                close_value = data[name][Factors.CLOSE]
+                open_value = data[name][Factors.OPEN]
+
+                self.assertEqual(calculated[name][0], close_value > 0)
+                self.assertEqual(calculated[name][1], open_value > 0)
+
     def testSecurityWhereValueHolderWithSymbolName(self):
         benchmark = SecurityLatestValueHolder(dependency='close')
 
@@ -976,7 +997,7 @@ class TestSecurityValueHolders(unittest.TestCase):
                                index=[1, 1, 1, 1, 2, 2, 2],
                                dtype=float)
 
-        expression = SecurityMovingMax(20, 'b') + SecurityMovingMinimum(20, 'c')
+        expression = SecurityMovingMax(20, 'b') + SecurityMovingMin(20, 'c')
         calculated = expression.transform(test_df, name='new_factor', category_field='code')
         expected = [13., 13., 13., 13., 11., 9, 9.]
 
@@ -988,7 +1009,7 @@ class TestSecurityValueHolders(unittest.TestCase):
                                index=[1, 2, 3, 4, 5, 6, 7],
                                dtype=float)
 
-        expression = SecurityMovingMax(20, 'b') + SecurityMovingMinimum(20, 'c')
+        expression = SecurityMovingMax(20, 'b') + SecurityMovingMin(20, 'c')
         calculated = expression.transform(test_df, name='new_factor')
         expected = [13., 13., 13., 13., 12., 11., 10.]
         np.testing.assert_array_almost_equal(calculated['new_factor'], expected)
